臺中市政府教育局全球資訊網 - 網路管理系統

- :::
- 回首頁
- |
- 網站導覽
- |
- FAQ
- |
- RSS
- |
- English
- |
- 憑證登入
- |
- 登入系統

:::
首頁 > 網路管理 > 網路管理系統
:::
公務帳號
《已登錄》
人
人氣指數
» 線上數: 38
» 今日數: 11784
» 本週數: 51111
» 本月數: 109733
» 今年數: 3400837
» 總次數: 22996267

## 臺中市教育網路中心 流量異常/資安回報

新增限制外部IP
限制IP 請使用CIDR表示法，ex: 163.17.40.0/24 或 163.17.40.1
限制理由
外部流量異常限制IP列表
[回上頁] 最近 [1日] [3日] [7日] [30日]

序 | 限制IP | 限制型態 | 流量 | 起限時間 | 距日 | 管理
--- | --- | --- | --- | --- | --- | ---
1 | 192.88.99.4 | Malware Provider | 手動設定 | 2016-11-08 22:49:17 | 2.02 | 封鎖
2 | 192.0.0.5 | Malware Provider | 手動設定 | 2016-11-08 22:46:44 | 2.02 |

* 市網中心對於外部IP(非中市網連線學校登記之IP)與市內連線單位有異常流量者逕行封鎖24小時，24小時後自動解除封鎖 * 外部IP若被封鎖需要解除，請直接與網路中心連絡。 | 網頁設計 台中市網路中心網路組 黃國順 張本和 2011.5.30

臺中市政府教育局版權所有 Copyright © 2011 - 2016. All Rights Reserved.

最佳瀏覽解析度 1024x768px. 建議使用瀏覽器 Firefox5.0以上或IE8.0以上或google chrome版本瀏覽本站.

臺中市政府教育局地址：42007 臺中市豐原區陽明街36號 【交通位置及停車資訊】【地圖】

市話總機代表號: 04-22289111 【各科室電話分機】 【教育局組織架構圖】 廉政檢舉【電話及傳真】【信箱】

辦公時間：8:00-17:00，中午休息時間：12:00-13:00 ‧彈性上下班時間：8:00-8:30、13:00-13:30、17:00-17:30

【網站資訊安全及個人隱私權宣告】 【網站服務條款】 【TC根憑證】 【TC中繼憑證】

最後更新時間: 2016-11-10 23:10:59